@@ -41,4 +41,18 @@ def test_TStatistic():
     voc = Vocabulary(day, lang="En")
     tstats = TStatistic(voc.voc)
     value = tstats.compute("of~the")
-    assert value > 655
\ No newline at end of file
+    assert value > 655
+
+
+def test_likelihood_ratios():
+    from text_models.utils import LikelihoodRatios
+    from text_models import Vocabulary
+    day = dict(year=2020, month=2, day=14)
+    voc = Vocabulary(day, lang="En")
+    tstats = LikelihoodRatios(voc.voc)
+    value = tstats.compute("of~the")
+    assert tstats.compute("my~us") == 0
+    assert tstats.compute("imtreety_~the") > 7748
+    # [tstats.compute(k) for k in voc if k.count("~")]
+    assert value > 4177118
+
